@@ -68,8 +68,7 @@ public:
     Private(bool localOnly, KDirSelectDialog *parent)
         : m_parent(parent),
           m_localOnly(localOnly),
-          m_comboLocked(false),
-          m_urlCombo(nullptr)
+          m_comboLocked(false)
     {
     }
 
@@ -87,21 +86,21 @@ public:
     void slotDelete();
     void slotProperties();
 
-    KDirSelectDialog *m_parent;
+    KDirSelectDialog *const m_parent;
     bool m_localOnly : 1;
     bool m_comboLocked : 1;
     QUrl m_rootUrl;
     QUrl m_startDir;
-    KFileTreeView *m_treeView;
-    QMenu *m_contextMenu;
-    KActionCollection *m_actions;
-    KFilePlacesView *m_placesView;
-    KHistoryComboBox *m_urlCombo;
+    KFileTreeView *m_treeView = nullptr;
+    QMenu *m_contextMenu = nullptr;
+    KActionCollection *m_actions = nullptr;
+    KFilePlacesView *m_placesView = nullptr;
+    KHistoryComboBox *m_urlCombo = nullptr;
     QString m_recentDirClass;
     QUrl m_startURL;
-    QAction *moveToTrash;
-    QAction *deleteAction;
-    QAction *showHiddenFoldersAction;
+    QAction *moveToTrash = nullptr;
+    QAction *deleteAction = nullptr;
+    QAction *showHiddenFoldersAction = nullptr;
 };
 
 void KDirSelectDialog::Private::readConfig(const KSharedConfig::Ptr &config, const QString &group)
@@ -147,11 +146,7 @@ void KDirSelectDialog::Private::slotMkdir()
     bool exists = false;
     QUrl folderurl(m_parent->url());
 
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-    const QStringList dirs = directory.split(QLatin1Char('/'), QString::SkipEmptyParts);
-#else
     const QStringList dirs = directory.split(QLatin1Char('/'), Qt::SkipEmptyParts);
-#endif
     QStringList::ConstIterator it = dirs.begin();
 
     for (; it != dirs.end(); ++it) {
@@ -354,7 +349,7 @@ KDirSelectDialog::KDirSelectDialog(const QUrl &startDir, bool localOnly, QWidget
     QAction *newFolder = new QAction(i18nc("@action:inmenu", "New Folder..."), this);
     d->m_actions->addAction(newFolder->objectName(), newFolder);
     newFolder->setIcon(QIcon::fromTheme(QStringLiteral("folder-new")));
-    newFolder->setShortcut(Qt::Key_F10);
+    newFolder->setShortcuts(KStandardShortcut::createFolder());
     connect(newFolder, SIGNAL(triggered(bool)), this, SLOT(slotNewFolder()));
     d->m_contextMenu->addAction(newFolder);
 
@@ -368,7 +363,7 @@ KDirSelectDialog::KDirSelectDialog(const QUrl &startDir, bool localOnly, QWidget
     d->deleteAction = new QAction(i18nc("@action:inmenu", "Delete"), this);
     d->m_actions->addAction(d->deleteAction->objectName(), d->deleteAction);
     d->deleteAction->setIcon(QIcon::fromTheme(QStringLiteral("edit-delete")));
-    d->deleteAction->setShortcut(Qt::SHIFT + Qt::Key_Delete);
+    d->deleteAction->setShortcut(Qt::SHIFT | Qt::Key_Delete);
     connect(d->deleteAction, SIGNAL(triggered(bool)), this, SLOT(slotDelete()));
     d->m_contextMenu->addAction(d->deleteAction);
 
@@ -384,7 +379,7 @@ KDirSelectDialog::KDirSelectDialog(const QUrl &startDir, bool localOnly, QWidget
     QAction *propertiesAction = new QAction(i18nc("@action:inmenu", "Properties"), this);
     d->m_actions->addAction(propertiesAction->objectName(), propertiesAction);
     propertiesAction->setIcon(QIcon::fromTheme(QStringLiteral("document-properties")));
-    propertiesAction->setShortcut(Qt::ALT + Qt::Key_Return);
+    propertiesAction->setShortcut(Qt::ALT | Qt::Key_Return);
     connect(propertiesAction, SIGNAL(triggered(bool)), this, SLOT(slotProperties()));
     d->m_contextMenu->addAction(propertiesAction);
 
@@ -568,6 +563,16 @@ QList<QUrl> KDirSelectDialog::selectedFiles()
     return QList<QUrl>() << url();
 }
 
+void KDirSelectDialog::setOkButtonText(const QString &text)
+{
+    m_buttons->button(QDialogButtonBox::Ok)->setText(text);
+}
+
+void KDirSelectDialog::setCancelButtonText(const QString &text)
+{
+    m_buttons->button(QDialogButtonBox::Cancel)->setText(text);
+}
+
 void KDirSelectDialog::setDirectory(const QUrl &directory)
 {
     setCurrentUrl(directory);
